Python library to interact with Apple's Reminder application.

The available commands are:
create_from   Create all reminders from specified json files
new           New reminder from specified parameters

